Class: Aws::RTBFabric::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RTBFabric::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-rtbfabric/client.rb,
sig/client.rbs
Overview
An API client for RTBFabric. To construct a client, you need to configure a :region and :credentials.
client = Aws::RTBFabric::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptLinkResponseSuccess, _AssociateCertificateResponseSuccess, _CreateInboundExternalLinkResponseSuccess, _CreateLinkResponseSuccess, _CreateLinkRoutingRuleResponseSuccess, _CreateOutboundExternalLinkResponseSuccess, _CreateRequesterGatewayResponseSuccess, _CreateResponderGatewayResponseSuccess, _DeleteInboundExternalLinkResponseSuccess, _DeleteLinkResponseSuccess, _DeleteLinkRoutingRuleResponseSuccess, _DeleteOutboundExternalLinkResponseSuccess, _DeleteRequesterGatewayResponseSuccess, _DeleteResponderGatewayResponseSuccess, _DisassociateCertificateResponseSuccess, _GetCertificateAssociationResponseSuccess, _GetInboundExternalLinkResponseSuccess, _GetLinkResponseSuccess, _GetLinkRoutingRuleResponseSuccess, _GetOutboundExternalLinkResponseSuccess, _GetRequesterGatewayResponseSuccess, _GetResponderGatewayResponseSuccess, _ListCertificateAssociationsResponseSuccess, _ListLinkRoutingRulesResponseSuccess, _ListLinksResponseSuccess, _ListRequesterGatewaysResponseSuccess, _ListResponderGatewaysResponseSuccess, _ListTagsForResourceResponseSuccess, _RejectLinkResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateLinkModuleFlowResponseSuccess, _UpdateLinkResponseSuccess, _UpdateLinkRoutingRuleResponseSuccess, _UpdateRequesterGatewayResponseSuccess, _UpdateResponderGatewayResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_link(params = {}) ⇒ Types::AcceptLinkResponse
Accepts a link request between gateways.
-
#associate_certificate(params = {}) ⇒ Types::AssociateCertificateResponse
Associates an ACM certificate with a responder gateway.
-
#create_inbound_external_link(params = {}) ⇒ Types::CreateInboundExternalLinkResponse
Creates an inbound external link.
-
#create_link(params = {}) ⇒ Types::CreateLinkResponse
Creates a new link between gateways.
-
#create_link_routing_rule(params = {}) ⇒ Types::CreateLinkRoutingRuleResponse
Creates a routing rule for a link.
-
#create_outbound_external_link(params = {}) ⇒ Types::CreateOutboundExternalLinkResponse
Creates an outbound external link.
-
#create_requester_gateway(params = {}) ⇒ Types::CreateRequesterGatewayResponse
Creates a requester gateway.
-
#create_responder_gateway(params = {}) ⇒ Types::CreateResponderGatewayResponse
Creates a responder gateway.
-
#delete_inbound_external_link(params = {}) ⇒ Types::DeleteInboundExternalLinkResponse
Deletes an inbound external link.
-
#delete_link(params = {}) ⇒ Types::DeleteLinkResponse
Deletes a link between gateways.
-
#delete_link_routing_rule(params = {}) ⇒ Types::DeleteLinkRoutingRuleResponse
Deletes a routing rule from a link.
-
#delete_outbound_external_link(params = {}) ⇒ Types::DeleteOutboundExternalLinkResponse
Deletes an outbound external link.
-
#delete_requester_gateway(params = {}) ⇒ Types::DeleteRequesterGatewayResponse
Deletes a requester gateway.
-
#delete_responder_gateway(params = {}) ⇒ Types::DeleteResponderGatewayResponse
Deletes a responder gateway.
-
#disassociate_certificate(params = {}) ⇒ Types::DisassociateCertificateResponse
Removes a certificate association from a responder gateway.
-
#get_certificate_association(params = {}) ⇒ Types::GetCertificateAssociationResponse
Retrieves the details of a certificate association with a responder gateway.
-
#get_inbound_external_link(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Retrieves information about an inbound external link.
-
#get_link(params = {}) ⇒ Types::GetLinkResponse
Retrieves information about a link between gateways.
-
#get_link_routing_rule(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Retrieves the details of a routing rule for a link.
-
#get_outbound_external_link(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Retrieves information about an outbound external link.
-
#get_requester_gateway(params = {}) ⇒ Types::GetRequesterGatewayResponse
Retrieves information about a requester gateway.
-
#get_responder_gateway(params = {}) ⇒ Types::GetResponderGatewayResponse
Retrieves information about a responder gateway.
-
#list_certificate_associations(params = {}) ⇒ Types::ListCertificateAssociationsResponse
Lists the certificate associations for a responder gateway.
-
#list_link_routing_rules(params = {}) ⇒ Types::ListLinkRoutingRulesResponse
Lists the routing rules for a link.
-
#list_links(params = {}) ⇒ Types::ListLinksResponse
Lists links associated with gateways.
-
#list_requester_gateways(params = {}) ⇒ Types::ListRequesterGatewaysResponse
Lists requester gateways.
-
#list_responder_gateways(params = {}) ⇒ Types::ListResponderGatewaysResponse
Lists reponder gateways.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
-
#reject_link(params = {}) ⇒ Types::RejectLinkResponse
Rejects a link request between gateways.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_link(params = {}) ⇒ Types::UpdateLinkResponse
Updates the configuration of a link between gateways.
-
#update_link_module_flow(params = {}) ⇒ Types::UpdateLinkModuleFlowResponse
Updates a link module flow.
-
#update_link_routing_rule(params = {}) ⇒ Types::UpdateLinkRoutingRuleResponse
Updates a routing rule for a link.
-
#update_requester_gateway(params = {}) ⇒ Types::UpdateRequesterGatewayResponse
Updates a requester gateway.
-
#update_responder_gateway(params = {}) ⇒ Types::UpdateResponderGatewayResponse
Updates a responder gateway.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3870 3871 3872 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3870 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3873 3874 3875 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3873 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_link(params = {}) ⇒ Types::AcceptLinkResponse
Accepts a link request between gateways.
When a requester gateway requests to link with a responder gateway, the responder can use this operation to accept the link request and establish the connection.
97 |
# File 'sig/client.rbs', line 97
def accept_link: (
|
#associate_certificate(params = {}) ⇒ Types::AssociateCertificateResponse
Associates an ACM certificate with a responder gateway.
113 |
# File 'sig/client.rbs', line 113
def associate_certificate: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3702 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RTBFabric') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-rtbfabric' context[:gem_version] = '1.15.0' Seahorse::Client::Request.new(handlers, context) end |
#create_inbound_external_link(params = {}) ⇒ Types::CreateInboundExternalLinkResponse
Creates an inbound external link.
128 |
# File 'sig/client.rbs', line 128
def create_inbound_external_link: (
|
#create_link(params = {}) ⇒ Types::CreateLinkResponse
Creates a new link between gateways.
Establishes a connection that allows gateways to communicate and exchange bid requests and responses.
154 |
# File 'sig/client.rbs', line 154
def create_link: (
|
#create_link_routing_rule(params = {}) ⇒ Types::CreateLinkRoutingRuleResponse
Creates a routing rule for a link.
Routing rules use priority-based evaluation where lower priority numbers are evaluated first. Each rule specifies conditions that must all match for the rule to apply.
172 |
# File 'sig/client.rbs', line 172
def create_link_routing_rule: (
|
#create_outbound_external_link(params = {}) ⇒ Types::CreateOutboundExternalLinkResponse
Creates an outbound external link.
189 |
# File 'sig/client.rbs', line 189
def create_outbound_external_link: (
|
#create_requester_gateway(params = {}) ⇒ Types::CreateRequesterGatewayResponse
Creates a requester gateway.
206 |
# File 'sig/client.rbs', line 206
def create_requester_gateway: (
|
#create_responder_gateway(params = {}) ⇒ Types::CreateResponderGatewayResponse
Creates a responder gateway.
A domain name or managed endpoint is required.
224 |
# File 'sig/client.rbs', line 224
def create_responder_gateway: (
|
#delete_inbound_external_link(params = {}) ⇒ Types::DeleteInboundExternalLinkResponse
Deletes an inbound external link.
251 |
# File 'sig/client.rbs', line 251
def delete_inbound_external_link: (
|
#delete_link(params = {}) ⇒ Types::DeleteLinkResponse
Deletes a link between gateways.
Permanently removes the connection between gateways. This action cannot be undone.
263 |
# File 'sig/client.rbs', line 263
def delete_link: (
|
#delete_link_routing_rule(params = {}) ⇒ Types::DeleteLinkRoutingRuleResponse
Deletes a routing rule from a link.
275 |
# File 'sig/client.rbs', line 275
def delete_link_routing_rule: (
|
#delete_outbound_external_link(params = {}) ⇒ Types::DeleteOutboundExternalLinkResponse
Deletes an outbound external link.
288 |
# File 'sig/client.rbs', line 288
def delete_outbound_external_link: (
|
#delete_requester_gateway(params = {}) ⇒ Types::DeleteRequesterGatewayResponse
Deletes a requester gateway.
300 |
# File 'sig/client.rbs', line 300
def delete_requester_gateway: (
|
#delete_responder_gateway(params = {}) ⇒ Types::DeleteResponderGatewayResponse
Deletes a responder gateway.
311 |
# File 'sig/client.rbs', line 311
def delete_responder_gateway: (
|
#disassociate_certificate(params = {}) ⇒ Types::DisassociateCertificateResponse
Removes a certificate association from a responder gateway.
323 |
# File 'sig/client.rbs', line 323
def disassociate_certificate: (
|
#get_certificate_association(params = {}) ⇒ Types::GetCertificateAssociationResponse
Retrieves the details of a certificate association with a responder gateway.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* certificate_associated
* certificate_disassociated
338 |
# File 'sig/client.rbs', line 338
def get_certificate_association: (
|
#get_inbound_external_link(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Retrieves information about an inbound external link.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* inbound_external_link_active
* inbound_external_link_deleted
360 |
# File 'sig/client.rbs', line 360
def get_inbound_external_link: (
|
#get_link(params = {}) ⇒ Types::GetLinkResponse
Retrieves information about a link between gateways.
Returns detailed information about the link configuration, status, and associated gateways.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* link_accepted
* link_active
* link_deleted
385 |
# File 'sig/client.rbs', line 385
def get_link: (
|
#get_link_routing_rule(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Retrieves the details of a routing rule for a link.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* link_routing_rule_active
* link_routing_rule_deleted
404 |
# File 'sig/client.rbs', line 404
def get_link_routing_rule: (
|
#get_outbound_external_link(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Retrieves information about an outbound external link.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* outbound_external_link_active
* outbound_external_link_deleted
427 |
# File 'sig/client.rbs', line 427
def get_outbound_external_link: (
|
#get_requester_gateway(params = {}) ⇒ Types::GetRequesterGatewayResponse
Retrieves information about a requester gateway.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* requester_gateway_active
* requester_gateway_deleted
449 |
# File 'sig/client.rbs', line 449
def get_requester_gateway: (
|
#get_responder_gateway(params = {}) ⇒ Types::GetResponderGatewayResponse
Retrieves information about a responder gateway.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* responder_gateway_active
* responder_gateway_deleted
479 |
# File 'sig/client.rbs', line 479
def get_responder_gateway: (
|
#list_certificate_associations(params = {}) ⇒ Types::ListCertificateAssociationsResponse
Lists the certificate associations for a responder gateway.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
490 |
# File 'sig/client.rbs', line 490
def list_certificate_associations: (
|
#list_link_routing_rules(params = {}) ⇒ Types::ListLinkRoutingRulesResponse
Lists the routing rules for a link.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
503 |
# File 'sig/client.rbs', line 503
def list_link_routing_rules: (
|
#list_links(params = {}) ⇒ Types::ListLinksResponse
Lists links associated with gateways.
Returns a list of all links for the specified gateways, including their status and configuration details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
517 |
# File 'sig/client.rbs', line 517
def list_links: (
|
#list_requester_gateways(params = {}) ⇒ Types::ListRequesterGatewaysResponse
Lists requester gateways.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
530 |
# File 'sig/client.rbs', line 530
def list_requester_gateways: (
|
#list_responder_gateways(params = {}) ⇒ Types::ListResponderGatewaysResponse
Lists reponder gateways.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
542 |
# File 'sig/client.rbs', line 542
def list_responder_gateways: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
553 |
# File 'sig/client.rbs', line 553
def list_tags_for_resource: (
|
#reject_link(params = {}) ⇒ Types::RejectLinkResponse
Rejects a link request between gateways.
When a requester gateway requests to link with a responder gateway, the responder can use this operation to decline the link request.
574 |
# File 'sig/client.rbs', line 574
def reject_link: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
584 |
# File 'sig/client.rbs', line 584
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
594 |
# File 'sig/client.rbs', line 594
def untag_resource: (
|
#update_link(params = {}) ⇒ Types::UpdateLinkResponse
Updates the configuration of a link between gateways.
Allows you to modify settings and parameters for an existing link.
606 |
# File 'sig/client.rbs', line 606
def update_link: (
|
#update_link_module_flow(params = {}) ⇒ Types::UpdateLinkModuleFlowResponse
Updates a link module flow.
621 |
# File 'sig/client.rbs', line 621
def update_link_module_flow: (
|
#update_link_routing_rule(params = {}) ⇒ Types::UpdateLinkRoutingRuleResponse
Updates a routing rule for a link.
675 |
# File 'sig/client.rbs', line 675
def update_link_routing_rule: (
|
#update_requester_gateway(params = {}) ⇒ Types::UpdateRequesterGatewayResponse
Updates a requester gateway.
690 |
# File 'sig/client.rbs', line 690
def update_requester_gateway: (
|
#update_responder_gateway(params = {}) ⇒ Types::UpdateResponderGatewayResponse
Updates a responder gateway.
703 |
# File 'sig/client.rbs', line 703
def update_responder_gateway: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| certificate_associated | #get_certificate_association | 15 | 8 |
| certificate_disassociated | #get_certificate_association | 15 | 8 |
| inbound_external_link_active | #get_inbound_external_link | 30 | 5 |
| inbound_external_link_deleted | #get_inbound_external_link | 30 | 5 |
| link_accepted | #get_link | 30 | 5 |
| link_active | #get_link | 30 | 5 |
| link_deleted | #get_link | 30 | 5 |
| link_routing_rule_active | #get_link_routing_rule | 5 | 24 |
| link_routing_rule_deleted | #get_link_routing_rule | 5 | 24 |
| outbound_external_link_active | #get_outbound_external_link | 30 | 5 |
| outbound_external_link_deleted | #get_outbound_external_link | 30 | 5 |
| requester_gateway_active | #get_requester_gateway | 30 | 5 |
| requester_gateway_deleted | #get_requester_gateway | 30 | 5 |
| responder_gateway_active | #get_responder_gateway | 30 | 5 |
| responder_gateway_deleted | #get_responder_gateway | 30 | 5 |
721 |
# File 'sig/client.rbs', line 721
def wait_until: (:certificate_associated waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3830 3831 3832 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3830 def waiter_names waiters.keys end |