Class: Aws::RTBFabric::Types::AutoScalingGroupsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::AutoScalingGroupsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Describes the configuration of an auto scaling group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_group_names ⇒ Array<String>
The names of the auto scaling group.
-
#health_check_config ⇒ Types::HealthCheckConfig
The health check configuration for the Auto Scaling group managed endpoint.
-
#role_arn ⇒ String
The role ARN of the auto scaling group.
Instance Attribute Details
#auto_scaling_group_names ⇒ Array<String>
The names of the auto scaling group.
235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 235 class AutoScalingGroupsConfiguration < Struct.new( :auto_scaling_group_names, :role_arn, :health_check_config) SENSITIVE = [] include Aws::Structure end |
#health_check_config ⇒ Types::HealthCheckConfig
The health check configuration for the Auto Scaling group managed endpoint.
235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 235 class AutoScalingGroupsConfiguration < Struct.new( :auto_scaling_group_names, :role_arn, :health_check_config) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The role ARN of the auto scaling group.
235 236 237 238 239 240 241 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 235 class AutoScalingGroupsConfiguration < Struct.new( :auto_scaling_group_names, :role_arn, :health_check_config) SENSITIVE = [] include Aws::Structure end |