Class: Aws::RTBFabric::Types::CreateLinkRoutingRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::CreateLinkRoutingRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#conditions ⇒ Types::RuleCondition
The conditions for the routing rule.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#link_id ⇒ String
The unique identifier of the link.
-
#priority ⇒ Integer
The priority of the routing rule.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
Instance Attribute Details
#client_token ⇒ String
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a [UUID type of value].
If you don’t provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ‘ClientToken`, but with different parameters, the retry fails with an `IdempotentParameterMismatch` error.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 513 class CreateLinkRoutingRuleRequest < Struct.new( :client_token, :gateway_id, :link_id, :priority, :conditions, :tags) SENSITIVE = [] include Aws::Structure end |
#conditions ⇒ Types::RuleCondition
The conditions for the routing rule. All specified fields must match for the rule to apply. At least one condition field must be set.
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 513 class CreateLinkRoutingRuleRequest < Struct.new( :client_token, :gateway_id, :link_id, :priority, :conditions, :tags) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 513 class CreateLinkRoutingRuleRequest < Struct.new( :client_token, :gateway_id, :link_id, :priority, :conditions, :tags) SENSITIVE = [] include Aws::Structure end |
#link_id ⇒ String
The unique identifier of the link.
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 513 class CreateLinkRoutingRuleRequest < Struct.new( :client_token, :gateway_id, :link_id, :priority, :conditions, :tags) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The priority of the routing rule. Lower numbers are evaluated first. Valid values are 1 to 1000. Priority must be unique among non-deleted rules within a link.
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 513 class CreateLinkRoutingRuleRequest < Struct.new( :client_token, :gateway_id, :link_id, :priority, :conditions, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 513 class CreateLinkRoutingRuleRequest < Struct.new( :client_token, :gateway_id, :link_id, :priority, :conditions, :tags) SENSITIVE = [] include Aws::Structure end |