Class: Aws::RTBFabric::Types::CreateOutboundExternalLinkRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::CreateOutboundExternalLinkRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Types::LinkAttributes
Attributes of the link.
-
#client_token ⇒ String
The unique client token.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
-
#public_endpoint ⇒ String
The public endpoint of the link.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
Instance Attribute Details
#attributes ⇒ Types::LinkAttributes
Attributes of the link.
576 577 578 579 580 581 582 583 584 585 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 576 class CreateOutboundExternalLinkRequest < Struct.new( :client_token, :gateway_id, :attributes, :public_endpoint, :log_settings, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The unique client token.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
576 577 578 579 580 581 582 583 584 585 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 576 class CreateOutboundExternalLinkRequest < Struct.new( :client_token, :gateway_id, :attributes, :public_endpoint, :log_settings, :tags) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
576 577 578 579 580 581 582 583 584 585 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 576 class CreateOutboundExternalLinkRequest < Struct.new( :client_token, :gateway_id, :attributes, :public_endpoint, :log_settings, :tags) SENSITIVE = [] include Aws::Structure end |
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
576 577 578 579 580 581 582 583 584 585 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 576 class CreateOutboundExternalLinkRequest < Struct.new( :client_token, :gateway_id, :attributes, :public_endpoint, :log_settings, :tags) SENSITIVE = [] include Aws::Structure end |
#public_endpoint ⇒ String
The public endpoint of the link.
576 577 578 579 580 581 582 583 584 585 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 576 class CreateOutboundExternalLinkRequest < Struct.new( :client_token, :gateway_id, :attributes, :public_endpoint, :log_settings, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
576 577 578 579 580 581 582 583 584 585 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 576 class CreateOutboundExternalLinkRequest < Struct.new( :client_token, :gateway_id, :attributes, :public_endpoint, :log_settings, :tags) SENSITIVE = [] include Aws::Structure end |