Class: Aws::RTBFabric::Types::CreateResponderGatewayRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique client token.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description for the responder gateway.

Returns:

  • (String)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name for the responder gateway.

Returns:

  • (String)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_typeString

The type of gateway. Valid values are ‘EXTERNAL` or `INTERNAL`.

Returns:

  • (String)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#listener_configTypes::ListenerConfig

Listener configuration for the protocols (HTTP, HTTPS, or both) accepted by the gateway.



731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#managed_endpoint_configurationTypes::ManagedEndpointConfiguration

The configuration for the managed endpoint.



731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The networking port to use.

Returns:

  • (Integer)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The networking protocol to use.

Returns:

  • (String)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The unique identifiers of the security groups.

Returns:

  • (Array<String>)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The unique identifiers of the subnets.

Returns:

  • (Array<String>)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of the key-value pairs of the tag or tags to assign to the resource.

Returns:

  • (Hash<String,String>)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#trust_store_configurationTypes::TrustStoreConfiguration

The configuration of the trust store.



731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The unique identifier of the Virtual Private Cloud (VPC).

Returns:

  • (String)


731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731

class CreateResponderGatewayRequest < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :client_token,
  :description,
  :tags,
  :gateway_type)
  SENSITIVE = []
  include Aws::Structure
end