Class: Aws::RTBFabric::Types::GetInboundExternalLinkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesTypes::LinkAttributes

Attributes of the link.



1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#connectivity_typeString

The connectivity type of the link.

Returns:

  • (String)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp of when the inbound external link was created.

Returns:

  • (Time)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name.

Returns:

  • (String)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#flow_modulesArray<Types::ModuleConfiguration>

The configuration of flow modules.

Returns:



1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The unique identifier of the gateway.

Returns:

  • (String)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier of the link.

Returns:

  • (String)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_settingsTypes::LinkLogSettings

Settings for the application logs.



1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#pending_flow_modulesArray<Types::ModuleConfiguration>

The configuration of pending flow modules.

Returns:



1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the request.

Returns:

  • (String)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of the key-value pairs for the tag or tags assigned to the specified resource.

Returns:

  • (Hash<String,String>)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when the inbound external link was updated.

Returns:

  • (Time)


1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205

class GetInboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :domain_name,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end