Class: Aws::RTBFabric::Types::GetLinkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::GetLinkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Types::LinkAttributes
Attributes of the link.
-
#connectivity_type ⇒ String
The connectivity type of the link.
-
#created_at ⇒ Time
The timestamp of when the link was created.
-
#direction ⇒ String
The direction of the link.
-
#flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of flow modules.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#http_responder_allowed ⇒ Boolean
Boolean to specify if an HTTP responder is allowed.
-
#link_id ⇒ String
The unique identifier of the link.
-
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
-
#peer_gateway_id ⇒ String
The unique identifier of the peer gateway.
-
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of pending flow modules.
-
#status ⇒ String
The status of the link.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
-
#timeout_in_millis ⇒ Integer
The timeout value in milliseconds.
-
#updated_at ⇒ Time
The timestamp of when the link was updated.
Instance Attribute Details
#attributes ⇒ Types::LinkAttributes
Attributes of the link.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#connectivity_type ⇒ String
The connectivity type of the link.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the link was created.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#direction ⇒ String
The direction of the link.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of flow modules.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#http_responder_allowed ⇒ Boolean
Boolean to specify if an HTTP responder is allowed.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#link_id ⇒ String
The unique identifier of the link.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#peer_gateway_id ⇒ String
The unique identifier of the peer gateway.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of pending flow modules.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the link.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#timeout_in_millis ⇒ Integer
The timeout value in milliseconds.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the link was updated.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1302 class GetLinkResponse < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :http_responder_allowed, :timeout_in_millis) SENSITIVE = [] include Aws::Structure end |