Class: Aws::RTBFabric::Types::GetLinkRoutingRuleResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#conditions ⇒ Types::RuleCondition

The conditions for the routing rule.



1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp of when the routing rule was created.

Returns:

  • (Time)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_id ⇒ String

The unique identifier of the gateway.

Returns:

  • (String)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier of the link.

Returns:

  • (String)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#priority ⇒ Integer

The priority of the routing rule.

Returns:

  • (Integer)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_id ⇒ String

The unique identifier of the routing rule.

Returns:

  • (String)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the routing rule.

Returns:

  • (String)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A map of the key-value pairs for the tag or tags assigned to the specified resource.

Returns:

  • (Hash<String,String>)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp of when the routing rule was last updated.

Returns:

  • (Time)


1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1500

class GetLinkRoutingRuleResponse < Struct.new(
  :gateway_id,
  :link_id,
  :rule_id,
  :priority,
  :conditions,
  :status,
  :created_at,
  :updated_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end