Class: Aws::RTBFabric::Types::GetOutboundExternalLinkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributes ⇒ Types::LinkAttributes

Describes the attributes of a link.



1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#connectivity_type ⇒ String

The connectivity type of the link.

Returns:

  • (String)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The timestamp of when the outbound external link was created.

Returns:

  • (Time)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#flow_modules ⇒ Array<Types::ModuleConfiguration>

The configuration of flow modules.

Returns:



1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_id ⇒ String

The unique identifier of the gateway.

Returns:

  • (String)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier of the link.

Returns:

  • (String)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_settings ⇒ Types::LinkLogSettings

Settings for the application logs.



1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>

The configuration of pending flow modules.

Returns:



1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#public_endpoint ⇒ String

The public endpoint for the link.

Returns:

  • (String)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the request.

Returns:

  • (String)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A map of the key-value pairs for the tag or tags assigned to the specified resource.

Returns:

  • (Hash<String,String>)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

The timestamp of when the outbound external link was updated.

Returns:

  • (Time)


1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1582

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end