Class: Aws::RTBFabric::Types::LinkRoutingRuleSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::LinkRoutingRuleSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Summary of a routing rule for list responses
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conditions ⇒ Types::RuleCondition
The conditions for the routing rule.
-
#created_at ⇒ Time
The timestamp of when the routing rule was created.
-
#priority ⇒ Integer
The priority of the routing rule.
-
#rule_id ⇒ String
The unique identifier of the routing rule.
-
#status ⇒ String
The status of the routing rule.
-
#updated_at ⇒ Time
The timestamp of when the routing rule was last updated.
Instance Attribute Details
#conditions ⇒ Types::RuleCondition
The conditions for the routing rule.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1868 class LinkRoutingRuleSummary < Struct.new( :rule_id, :priority, :conditions, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the routing rule was created.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1868 class LinkRoutingRuleSummary < Struct.new( :rule_id, :priority, :conditions, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The priority of the routing rule.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1868 class LinkRoutingRuleSummary < Struct.new( :rule_id, :priority, :conditions, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
The unique identifier of the routing rule.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1868 class LinkRoutingRuleSummary < Struct.new( :rule_id, :priority, :conditions, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the routing rule.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1868 class LinkRoutingRuleSummary < Struct.new( :rule_id, :priority, :conditions, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the routing rule was last updated.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1868 class LinkRoutingRuleSummary < Struct.new( :rule_id, :priority, :conditions, :status, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |