Class: Aws::RTBFabric::Types::ListLinksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

Information about created links.



2170
2171
2172
2173
2174
2175
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2170

class ListLinksResponse < Struct.new(
  :links,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.

Returns:

  • (String)


2170
2171
2172
2173
2174
2175
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2170

class ListLinksResponse < Struct.new(
  :links,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end