Class: Aws::RTBFabric::Types::ListLinksResponseStructure
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ListLinksResponseStructure
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Describes a link.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Types::LinkAttributes
Describes attributes of a link.
-
#connectivity_type ⇒ String
The connectivity type of the link.
-
#created_at ⇒ Time
The timestamp of when the link was created.
-
#direction ⇒ String
The direction of the link.
-
#flow_modules ⇒ Array<Types::ModuleConfiguration>
Describes the configuration of flow modules.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#link_id ⇒ String
The unique identifier of the link.
-
#log_settings ⇒ Types::LinkLogSettings
Describes the settings for a link log.
-
#peer_gateway_id ⇒ String
The unique identifier of the peer gateway.
-
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
Describes the configuration of pending flow modules.
-
#public_endpoint ⇒ String
The public endpoint of the outbound link.
-
#status ⇒ String
The status of the link.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
-
#updated_at ⇒ Time
The timestamp of when the link was updated.
Instance Attribute Details
#attributes ⇒ Types::LinkAttributes
Describes attributes of a link.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#connectivity_type ⇒ String
The connectivity type of the link.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the link was created.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#direction ⇒ String
The direction of the link.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#flow_modules ⇒ Array<Types::ModuleConfiguration>
Describes the configuration of flow modules.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#link_id ⇒ String
The unique identifier of the link.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#log_settings ⇒ Types::LinkLogSettings
Describes the settings for a link log.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#peer_gateway_id ⇒ String
The unique identifier of the peer gateway.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
Describes the configuration of pending flow modules.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#public_endpoint ⇒ String
The public endpoint of the outbound link.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the link.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the link was updated.
2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2238 class ListLinksResponseStructure < Struct.new( :gateway_id, :peer_gateway_id, :status, :created_at, :updated_at, :direction, :flow_modules, :pending_flow_modules, :attributes, :log_settings, :connectivity_type, :link_id, :tags, :public_endpoint) SENSITIVE = [] include Aws::Structure end |