Class: Aws::RTBFabric::Types::RuleCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

The conditions for a routing rule. All specified fields must match for the rule to apply (AND logic). At least one condition field must be set.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#host_headerString

The exact host header value to match.

Returns:

  • (String)


2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2619

class RuleCondition < Struct.new(
  :host_header,
  :host_header_wildcard,
  :path_prefix,
  :path_exact,
  :query_string_equals,
  :query_string_exists)
  SENSITIVE = []
  include Aws::Structure
end

#host_header_wildcardString

A wildcard pattern for host header matching (for example, *.example.com).

Returns:

  • (String)


2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2619

class RuleCondition < Struct.new(
  :host_header,
  :host_header_wildcard,
  :path_prefix,
  :path_exact,
  :query_string_equals,
  :query_string_exists)
  SENSITIVE = []
  include Aws::Structure
end

#path_exactString

The exact path to match. Must start with /.

Returns:

  • (String)


2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2619

class RuleCondition < Struct.new(
  :host_header,
  :host_header_wildcard,
  :path_prefix,
  :path_exact,
  :query_string_equals,
  :query_string_exists)
  SENSITIVE = []
  include Aws::Structure
end

#path_prefixString

The path prefix to match. The request path must start with this value. Must start with /.

Returns:

  • (String)


2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2619

class RuleCondition < Struct.new(
  :host_header,
  :host_header_wildcard,
  :path_prefix,
  :path_exact,
  :query_string_equals,
  :query_string_exists)
  SENSITIVE = []
  include Aws::Structure
end

#query_string_equalsTypes::QueryStringKeyValuePair

A query string key-value pair that must be present and match exactly.



2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2619

class RuleCondition < Struct.new(
  :host_header,
  :host_header_wildcard,
  :path_prefix,
  :path_exact,
  :query_string_equals,
  :query_string_exists)
  SENSITIVE = []
  include Aws::Structure
end

#query_string_existsString

A query string key that must be present in the request (any value is accepted).

Returns:

  • (String)


2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2619

class RuleCondition < Struct.new(
  :host_header,
  :host_header_wildcard,
  :path_prefix,
  :path_exact,
  :query_string_equals,
  :query_string_exists)
  SENSITIVE = []
  include Aws::Structure
end