Class: Aws::RTBFabric::Types::UpdateLinkRoutingRuleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::UpdateLinkRoutingRuleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rule_id ⇒ String
The unique identifier of the routing rule.
-
#status ⇒ String
The status of the routing rule.
-
#updated_at ⇒ Time
The timestamp of when the routing rule was last updated.
Instance Attribute Details
#rule_id ⇒ String
The unique identifier of the routing rule.
2867 2868 2869 2870 2871 2872 2873 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2867 class UpdateLinkRoutingRuleResponse < Struct.new( :rule_id, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the routing rule.
2867 2868 2869 2870 2871 2872 2873 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2867 class UpdateLinkRoutingRuleResponse < Struct.new( :rule_id, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the routing rule was last updated.
2867 2868 2869 2870 2871 2872 2873 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2867 class UpdateLinkRoutingRuleResponse < Struct.new( :rule_id, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |