Class: Aws::RTBFabric::Waiters::CertificateAssociated
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::CertificateAssociated
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CertificateAssociated
constructor
A new instance of CertificateAssociated.
-
#wait(params = {}) ⇒ Types::GetCertificateAssociationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CertificateAssociated
Returns a new instance of CertificateAssociated.
98 99 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 98
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
147 148 149 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 147 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetCertificateAssociationResponse
Returns a response object which responds to the following methods:
- #gateway_id => String
- #acm_certificate_arn => String
- #status => String
- #associated_at => Time
- #updated_at => Time
142 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 142
def wait: (
|