Class: Aws::RTBFabric::Waiters::InboundExternalLinkActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::InboundExternalLinkActive
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InboundExternalLinkActive
constructor
A new instance of InboundExternalLinkActive.
-
#wait(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InboundExternalLinkActive
Returns a new instance of InboundExternalLinkActive.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 214 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_inbound_external_link, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "REJECTED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ISOLATED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
264 265 266 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 264 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#link_id => String
-
#status => String
-
#domain_name => String
-
#flow_modules => Array<Types::ModuleConfiguration>
-
#pending_flow_modules => Array<Types::ModuleConfiguration>
-
#attributes => Types::LinkAttributes
-
#created_at => Time
-
#updated_at => Time
-
#tags => Hash<String,String>
-
#log_settings => Types::LinkLogSettings
-
#connectivity_type => String
259 260 261 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 259 def wait(params = {}) @waiter.wait(client: @client, params: params) end |