Class: Aws::RTBFabric::Waiters::InboundExternalLinkDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::InboundExternalLinkDeleted
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ InboundExternalLinkDeleted
constructor
A new instance of InboundExternalLinkDeleted.
-
#wait(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ InboundExternalLinkDeleted
Returns a new instance of InboundExternalLinkDeleted.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 276 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_inbound_external_link, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "REJECTED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
314 315 316 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 314 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#link_id => String
-
#status => String
-
#domain_name => String
-
#flow_modules => Array<Types::ModuleConfiguration>
-
#pending_flow_modules => Array<Types::ModuleConfiguration>
-
#attributes => Types::LinkAttributes
-
#created_at => Time
-
#updated_at => Time
-
#tags => Hash<String,String>
-
#log_settings => Types::LinkLogSettings
-
#connectivity_type => String
309 310 311 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 309 def wait(params = {}) @waiter.wait(client: @client, params: params) end |