Class: Aws::RTBFabric::Waiters::LinkActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::LinkActive
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LinkActive
constructor
A new instance of LinkActive.
-
#wait(params = {}) ⇒ Types::GetLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LinkActive
Returns a new instance of LinkActive.
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 382 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_link, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "REJECTED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
426 427 428 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 426 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLinkResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#peer_gateway_id => String
-
#status => String
-
#created_at => Time
-
#updated_at => Time
-
#direction => String
-
#flow_modules => Array<Types::ModuleConfiguration>
-
#pending_flow_modules => Array<Types::ModuleConfiguration>
-
#attributes => Types::LinkAttributes
-
#log_settings => Types::LinkLogSettings
-
#connectivity_type => String
-
#link_id => String
-
#tags => Hash<String,String>
-
#http_responder_allowed => Boolean
-
#timeout_in_millis => Integer
421 422 423 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 421 def wait(params = {}) @waiter.wait(client: @client, params: params) end |