Class: Aws::RTBFabric::Waiters::LinkDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::LinkDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LinkDeleted
constructor
A new instance of LinkDeleted.
-
#wait(params = {}) ⇒ Types::GetLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LinkDeleted
Returns a new instance of LinkDeleted.
438 439 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 438
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
476 477 478 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 476 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLinkResponse
Returns a response object which responds to the following methods:
- #gateway_id => String
- #peer_gateway_id => String
- #status => String
- #created_at => Time
- #updated_at => Time
- #direction => String
- #flow_modules => Array<Types::ModuleConfiguration>
- #pending_flow_modules => Array<Types::ModuleConfiguration>
- #attributes => Types::LinkAttributes
- #log_settings => Types::LinkLogSettings
- #connectivity_type => String
- #link_id => String
- #tags => Hash<String,String>
- #http_responder_allowed => Boolean
- #timeout_in_millis => Integer
471 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 471
def wait: (
|