Class: Aws::RTBFabric::Waiters::LinkRoutingRuleActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::LinkRoutingRuleActive
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LinkRoutingRuleActive
constructor
A new instance of LinkRoutingRuleActive.
-
#wait(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LinkRoutingRuleActive
Returns a new instance of LinkRoutingRuleActive.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 488 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 24, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :get_link_routing_rule, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
526 527 528 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 526 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#link_id => String
-
#rule_id => String
-
#priority => Integer
-
#conditions => Types::RuleCondition
-
#status => String
-
#created_at => Time
-
#updated_at => Time
-
#tags => Hash<String,String>
521 522 523 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 521 def wait(params = {}) @waiter.wait(client: @client, params: params) end |