Class: Aws::RTBFabric::Waiters::LinkRoutingRuleDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::LinkRoutingRuleDeleted
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LinkRoutingRuleDeleted
constructor
A new instance of LinkRoutingRuleDeleted.
-
#wait(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LinkRoutingRuleDeleted
Returns a new instance of LinkRoutingRuleDeleted.
538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 538 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 24, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :get_link_routing_rule, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "DELETED" }, { "matcher" => "error", "state" => "success", "expected" => "ResourceNotFoundException" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
575 576 577 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 575 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#link_id => String
-
#rule_id => String
-
#priority => Integer
-
#conditions => Types::RuleCondition
-
#status => String
-
#created_at => Time
-
#updated_at => Time
-
#tags => Hash<String,String>
570 571 572 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 570 def wait(params = {}) @waiter.wait(client: @client, params: params) end |