Class: Aws::RTBFabric::Waiters::OutboundExternalLinkActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::OutboundExternalLinkActive
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ OutboundExternalLinkActive
constructor
A new instance of OutboundExternalLinkActive.
-
#wait(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ OutboundExternalLinkActive
Returns a new instance of OutboundExternalLinkActive.
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 587 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_outbound_external_link, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "REJECTED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ISOLATED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
637 638 639 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 637 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#link_id => String
-
#status => String
-
#public_endpoint => String
-
#flow_modules => Array<Types::ModuleConfiguration>
-
#pending_flow_modules => Array<Types::ModuleConfiguration>
-
#attributes => Types::LinkAttributes
-
#created_at => Time
-
#updated_at => Time
-
#tags => Hash<String,String>
-
#log_settings => Types::LinkLogSettings
-
#connectivity_type => String
632 633 634 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 632 def wait(params = {}) @waiter.wait(client: @client, params: params) end |