Class: Aws::RTBFabric::Waiters::OutboundExternalLinkDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::OutboundExternalLinkDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ OutboundExternalLinkDeleted
constructor
A new instance of OutboundExternalLinkDeleted.
-
#wait(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ OutboundExternalLinkDeleted
Returns a new instance of OutboundExternalLinkDeleted.
649 650 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 649
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
687 688 689 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 687 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Returns a response object which responds to the following methods:
- #gateway_id => String
- #link_id => String
- #status => String
- #public_endpoint => String
- #flow_modules => Array<Types::ModuleConfiguration>
- #pending_flow_modules => Array<Types::ModuleConfiguration>
- #attributes => Types::LinkAttributes
- #created_at => Time
- #updated_at => Time
- #tags => Hash<String,String>
- #log_settings => Types::LinkLogSettings
- #connectivity_type => String
682 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 682
def wait: (
|