Class: Aws::RTBFabric::Waiters::RequesterGatewayDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::RequesterGatewayDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RequesterGatewayDeleted
constructor
A new instance of RequesterGatewayDeleted.
-
#wait(params = {}) ⇒ Types::GetRequesterGatewayResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RequesterGatewayDeleted
Returns a new instance of RequesterGatewayDeleted.
749 750 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 749
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
786 787 788 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 786 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRequesterGatewayResponse
Returns a response object which responds to the following methods:
- #status => String
- #domain_name => String
- #description => String
- #created_at => Time
- #updated_at => Time
- #vpc_id => String
- #subnet_ids => Array<String>
- #security_group_ids => Array<String>
- #gateway_id => String
- #tags => Hash<String,String>
- #active_links_count => Integer
- #total_links_count => Integer
781 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 781
def wait: (
|