Class: Aws::RTBFabric::Waiters::ResponderGatewayActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::ResponderGatewayActive
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ResponderGatewayActive
constructor
A new instance of ResponderGatewayActive.
-
#wait(params = {}) ⇒ Types::GetResponderGatewayResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ResponderGatewayActive
Returns a new instance of ResponderGatewayActive.
798 799 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 798
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
836 837 838 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 836 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetResponderGatewayResponse
Returns a response object which responds to the following methods:
- #vpc_id => String
- #subnet_ids => Array<String>
- #security_group_ids => Array<String>
- #status => String
- #description => String
- #created_at => Time
- #updated_at => Time
- #domain_name => String
- #port => Integer
- #protocol => String
- #listener_config => Types::ListenerConfig
- #trust_store_configuration => Types::TrustStoreConfiguration
- #managed_endpoint_configuration => Types::ManagedEndpointConfiguration
- #gateway_id => String
- #tags => Hash<String,String>
- #active_links_count => Integer
- #total_links_count => Integer
- #inbound_links_count => Integer
- #links_requested_count => Integer
- #gateway_type => String
- #external_inbound_endpoint => String
831 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 831
def wait: (
|