Class: Aws::RTBFabric::Waiters::ResponderGatewayDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::ResponderGatewayDeleted
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ResponderGatewayDeleted
constructor
A new instance of ResponderGatewayDeleted.
-
#wait(params = {}) ⇒ Types::GetResponderGatewayResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ResponderGatewayDeleted
Returns a new instance of ResponderGatewayDeleted.
848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 848 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_responder_gateway, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "DELETED" }, { "matcher" => "error", "state" => "success", "expected" => "ResourceNotFoundException" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ERROR" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
885 886 887 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 885 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetResponderGatewayResponse
Returns a response object which responds to the following methods:
-
#vpc_id => String
-
#subnet_ids => Array<String>
-
#security_group_ids => Array<String>
-
#status => String
-
#description => String
-
#created_at => Time
-
#updated_at => Time
-
#domain_name => String
-
#port => Integer
-
#protocol => String
-
#listener_config => Types::ListenerConfig
-
#trust_store_configuration => Types::TrustStoreConfiguration
-
#managed_endpoint_configuration => Types::ManagedEndpointConfiguration
-
#gateway_id => String
-
#tags => Hash<String,String>
-
#active_links_count => Integer
-
#total_links_count => Integer
-
#inbound_links_count => Integer
-
#links_requested_count => Integer
-
#gateway_type => String
-
#external_inbound_endpoint => String
880 881 882 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 880 def wait(params = {}) @waiter.wait(client: @client, params: params) end |