Class: Aws::RTBFabric::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::RTBFabric::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-rtbfabric/client.rb
Overview
An API client for RTBFabric. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::RTBFabric::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_link(params = {}) ⇒ Types::AcceptLinkResponse
Accepts a link request between gateways.
-
#associate_certificate(params = {}) ⇒ Types::AssociateCertificateResponse
Associates an ACM certificate with a responder gateway.
-
#create_inbound_external_link(params = {}) ⇒ Types::CreateInboundExternalLinkResponse
Creates an inbound external link.
-
#create_link(params = {}) ⇒ Types::CreateLinkResponse
Creates a new link between gateways.
-
#create_link_routing_rule(params = {}) ⇒ Types::CreateLinkRoutingRuleResponse
Creates a routing rule for a link.
-
#create_outbound_external_link(params = {}) ⇒ Types::CreateOutboundExternalLinkResponse
Creates an outbound external link.
-
#create_requester_gateway(params = {}) ⇒ Types::CreateRequesterGatewayResponse
Creates a requester gateway.
-
#create_responder_gateway(params = {}) ⇒ Types::CreateResponderGatewayResponse
Creates a responder gateway.
-
#delete_inbound_external_link(params = {}) ⇒ Types::DeleteInboundExternalLinkResponse
Deletes an inbound external link.
-
#delete_link(params = {}) ⇒ Types::DeleteLinkResponse
Deletes a link between gateways.
-
#delete_link_routing_rule(params = {}) ⇒ Types::DeleteLinkRoutingRuleResponse
Deletes a routing rule from a link.
-
#delete_outbound_external_link(params = {}) ⇒ Types::DeleteOutboundExternalLinkResponse
Deletes an outbound external link.
-
#delete_requester_gateway(params = {}) ⇒ Types::DeleteRequesterGatewayResponse
Deletes a requester gateway.
-
#delete_responder_gateway(params = {}) ⇒ Types::DeleteResponderGatewayResponse
Deletes a responder gateway.
-
#disassociate_certificate(params = {}) ⇒ Types::DisassociateCertificateResponse
Removes a certificate association from a responder gateway.
-
#get_certificate_association(params = {}) ⇒ Types::GetCertificateAssociationResponse
Retrieves the details of a certificate association with a responder gateway.
-
#get_inbound_external_link(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Retrieves information about an inbound external link.
-
#get_link(params = {}) ⇒ Types::GetLinkResponse
Retrieves information about a link between gateways.
-
#get_link_routing_rule(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Retrieves the details of a routing rule for a link.
-
#get_outbound_external_link(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Retrieves information about an outbound external link.
-
#get_requester_gateway(params = {}) ⇒ Types::GetRequesterGatewayResponse
Retrieves information about a requester gateway.
-
#get_responder_gateway(params = {}) ⇒ Types::GetResponderGatewayResponse
Retrieves information about a responder gateway.
-
#list_certificate_associations(params = {}) ⇒ Types::ListCertificateAssociationsResponse
Lists the certificate associations for a responder gateway.
-
#list_link_routing_rules(params = {}) ⇒ Types::ListLinkRoutingRulesResponse
Lists the routing rules for a link.
-
#list_links(params = {}) ⇒ Types::ListLinksResponse
Lists links associated with gateways.
-
#list_requester_gateways(params = {}) ⇒ Types::ListRequesterGatewaysResponse
Lists requester gateways.
-
#list_responder_gateways(params = {}) ⇒ Types::ListResponderGatewaysResponse
Lists reponder gateways.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
-
#reject_link(params = {}) ⇒ Types::RejectLinkResponse
Rejects a link request between gateways.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_link(params = {}) ⇒ Types::UpdateLinkResponse
Updates the configuration of a link between gateways.
-
#update_link_module_flow(params = {}) ⇒ Types::UpdateLinkModuleFlowResponse
Updates a link module flow.
-
#update_link_routing_rule(params = {}) ⇒ Types::UpdateLinkRoutingRuleResponse
Updates a routing rule for a link.
-
#update_requester_gateway(params = {}) ⇒ Types::UpdateRequesterGatewayResponse
Updates a requester gateway.
-
#update_responder_gateway(params = {}) ⇒ Types::UpdateResponderGatewayResponse
Updates a responder gateway.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3870 3871 3872 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3870 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3873 3874 3875 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3873 def errors_module Errors end |
Instance Method Details
#accept_link(params = {}) ⇒ Types::AcceptLinkResponse
Accepts a link request between gateways.
When a requester gateway requests to link with a responder gateway, the responder can use this operation to accept the link request and establish the connection.
630 631 632 633 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 630 def accept_link(params = {}, = {}) req = build_request(:accept_link, params) req.send_request() end |
#associate_certificate(params = {}) ⇒ Types::AssociateCertificateResponse
Associates an ACM certificate with a responder gateway.
707 708 709 710 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 707 def associate_certificate(params = {}, = {}) req = build_request(:associate_certificate, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3702 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::RTBFabric') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-rtbfabric' context[:gem_version] = '1.13.0' Seahorse::Client::Request.new(handlers, context) end |
#create_inbound_external_link(params = {}) ⇒ Types::CreateInboundExternalLinkResponse
Creates an inbound external link.
806 807 808 809 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 806 def create_inbound_external_link(params = {}, = {}) req = build_request(:create_inbound_external_link, params) req.send_request() end |
#create_link(params = {}) ⇒ Types::CreateLinkResponse
Creates a new link between gateways.
Establishes a connection that allows gateways to communicate and exchange bid requests and responses.
976 977 978 979 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 976 def create_link(params = {}, = {}) req = build_request(:create_link, params) req.send_request() end |
#create_link_routing_rule(params = {}) ⇒ Types::CreateLinkRoutingRuleResponse
Creates a routing rule for a link.
Routing rules use priority-based evaluation where lower priority numbers are evaluated first. Each rule specifies conditions that must all match for the rule to apply.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1090 def create_link_routing_rule(params = {}, = {}) req = build_request(:create_link_routing_rule, params) req.send_request() end |
#create_outbound_external_link(params = {}) ⇒ Types::CreateOutboundExternalLinkResponse
Creates an outbound external link.
1191 1192 1193 1194 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1191 def create_outbound_external_link(params = {}, = {}) req = build_request(:create_outbound_external_link, params) req.send_request() end |
#create_requester_gateway(params = {}) ⇒ Types::CreateRequesterGatewayResponse
Creates a requester gateway.
1274 1275 1276 1277 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1274 def create_requester_gateway(params = {}, = {}) req = build_request(:create_requester_gateway, params) req.send_request() end |
#create_responder_gateway(params = {}) ⇒ Types::CreateResponderGatewayResponse
Creates a responder gateway.
A domain name or managed endpoint is required.
1419 1420 1421 1422 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1419 def create_responder_gateway(params = {}, = {}) req = build_request(:create_responder_gateway, params) req.send_request() end |
#delete_inbound_external_link(params = {}) ⇒ Types::DeleteInboundExternalLinkResponse
Deletes an inbound external link.
1469 1470 1471 1472 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1469 def delete_inbound_external_link(params = {}, = {}) req = build_request(:delete_inbound_external_link, params) req.send_request() end |
#delete_link(params = {}) ⇒ Types::DeleteLinkResponse
Deletes a link between gateways.
Permanently removes the connection between gateways. This action cannot be undone.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1522 def delete_link(params = {}, = {}) req = build_request(:delete_link, params) req.send_request() end |
#delete_link_routing_rule(params = {}) ⇒ Types::DeleteLinkRoutingRuleResponse
Deletes a routing rule from a link.
1577 1578 1579 1580 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1577 def delete_link_routing_rule(params = {}, = {}) req = build_request(:delete_link_routing_rule, params) req.send_request() end |
#delete_outbound_external_link(params = {}) ⇒ Types::DeleteOutboundExternalLinkResponse
Deletes an outbound external link.
1627 1628 1629 1630 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1627 def delete_outbound_external_link(params = {}, = {}) req = build_request(:delete_outbound_external_link, params) req.send_request() end |
#delete_requester_gateway(params = {}) ⇒ Types::DeleteRequesterGatewayResponse
Deletes a requester gateway.
1672 1673 1674 1675 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1672 def delete_requester_gateway(params = {}, = {}) req = build_request(:delete_requester_gateway, params) req.send_request() end |
#delete_responder_gateway(params = {}) ⇒ Types::DeleteResponderGatewayResponse
Deletes a responder gateway.
1717 1718 1719 1720 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1717 def delete_responder_gateway(params = {}, = {}) req = build_request(:delete_responder_gateway, params) req.send_request() end |
#disassociate_certificate(params = {}) ⇒ Types::DisassociateCertificateResponse
Removes a certificate association from a responder gateway.
1770 1771 1772 1773 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1770 def disassociate_certificate(params = {}, = {}) req = build_request(:disassociate_certificate, params) req.send_request() end |
#get_certificate_association(params = {}) ⇒ Types::GetCertificateAssociationResponse
Retrieves the details of a certificate association with a responder gateway.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* certificate_associated
* certificate_disassociated
1836 1837 1838 1839 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1836 def get_certificate_association(params = {}, = {}) req = build_request(:get_certificate_association, params) req.send_request() end |
#get_inbound_external_link(params = {}) ⇒ Types::GetInboundExternalLinkResponse
Retrieves information about an inbound external link.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* inbound_external_link_active
* inbound_external_link_deleted
1960 1961 1962 1963 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 1960 def get_inbound_external_link(params = {}, = {}) req = build_request(:get_inbound_external_link, params) req.send_request() end |
#get_link(params = {}) ⇒ Types::GetLinkResponse
Retrieves information about a link between gateways.
Returns detailed information about the link configuration, status, and associated gateways.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* link_accepted
* link_active
* link_deleted
2094 2095 2096 2097 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2094 def get_link(params = {}, = {}) req = build_request(:get_link, params) req.send_request() end |
#get_link_routing_rule(params = {}) ⇒ Types::GetLinkRoutingRuleResponse
Retrieves the details of a routing rule for a link.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* link_routing_rule_active
* link_routing_rule_deleted
2185 2186 2187 2188 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2185 def get_link_routing_rule(params = {}, = {}) req = build_request(:get_link_routing_rule, params) req.send_request() end |
#get_outbound_external_link(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Retrieves information about an outbound external link.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* outbound_external_link_active
* outbound_external_link_deleted
2309 2310 2311 2312 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2309 def get_outbound_external_link(params = {}, = {}) req = build_request(:get_outbound_external_link, params) req.send_request() end |
#get_requester_gateway(params = {}) ⇒ Types::GetRequesterGatewayResponse
Retrieves information about a requester gateway.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* requester_gateway_active
* requester_gateway_deleted
2397 2398 2399 2400 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2397 def get_requester_gateway(params = {}, = {}) req = build_request(:get_requester_gateway, params) req.send_request() end |
#get_responder_gateway(params = {}) ⇒ Types::GetResponderGatewayResponse
Retrieves information about a responder gateway.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* responder_gateway_active
* responder_gateway_deleted
2524 2525 2526 2527 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2524 def get_responder_gateway(params = {}, = {}) req = build_request(:get_responder_gateway, params) req.send_request() end |
#list_certificate_associations(params = {}) ⇒ Types::ListCertificateAssociationsResponse
Lists the certificate associations for a responder gateway.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2600 2601 2602 2603 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2600 def list_certificate_associations(params = {}, = {}) req = build_request(:list_certificate_associations, params) req.send_request() end |
#list_link_routing_rules(params = {}) ⇒ Types::ListLinkRoutingRulesResponse
Lists the routing rules for a link.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2693 2694 2695 2696 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2693 def list_link_routing_rules(params = {}, = {}) req = build_request(:list_link_routing_rules, params) req.send_request() end |
#list_links(params = {}) ⇒ Types::ListLinksResponse
Lists links associated with gateways.
Returns a list of all links for the specified gateways, including their status and configuration details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2827 2828 2829 2830 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2827 def list_links(params = {}, = {}) req = build_request(:list_links, params) req.send_request() end |
#list_requester_gateways(params = {}) ⇒ Types::ListRequesterGatewaysResponse
Lists requester gateways.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2908 2909 2910 2911 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2908 def list_requester_gateways(params = {}, = {}) req = build_request(:list_requester_gateways, params) req.send_request() end |
#list_responder_gateways(params = {}) ⇒ Types::ListResponderGatewaysResponse
Lists reponder gateways.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2989 2990 2991 2992 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 2989 def list_responder_gateways(params = {}, = {}) req = build_request(:list_responder_gateways, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
3036 3037 3038 3039 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3036 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#reject_link(params = {}) ⇒ Types::RejectLinkResponse
Rejects a link request between gateways.
When a requester gateway requests to link with a responder gateway, the responder can use this operation to decline the link request.
3156 3157 3158 3159 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3156 def reject_link(params = {}, = {}) req = build_request(:reject_link, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
3202 3203 3204 3205 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3202 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
3246 3247 3248 3249 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3246 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_link(params = {}) ⇒ Types::UpdateLinkResponse
Updates the configuration of a link between gateways.
Allows you to modify settings and parameters for an existing link.
3321 3322 3323 3324 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3321 def update_link(params = {}, = {}) req = build_request(:update_link, params) req.send_request() end |
#update_link_module_flow(params = {}) ⇒ Types::UpdateLinkModuleFlowResponse
Updates a link module flow.
3440 3441 3442 3443 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3440 def update_link_module_flow(params = {}, = {}) req = build_request(:update_link_module_flow, params) req.send_request() end |
#update_link_routing_rule(params = {}) ⇒ Types::UpdateLinkRoutingRuleResponse
Updates a routing rule for a link.
3524 3525 3526 3527 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3524 def update_link_routing_rule(params = {}, = {}) req = build_request(:update_link_routing_rule, params) req.send_request() end |
#update_requester_gateway(params = {}) ⇒ Types::UpdateRequesterGatewayResponse
Updates a requester gateway.
3582 3583 3584 3585 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3582 def update_requester_gateway(params = {}, = {}) req = build_request(:update_requester_gateway, params) req.send_request() end |
#update_responder_gateway(params = {}) ⇒ Types::UpdateResponderGatewayResponse
Updates a responder gateway.
3693 3694 3695 3696 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3693 def update_responder_gateway(params = {}, = {}) req = build_request(:update_responder_gateway, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | —————————— | ———————————— | ——– | ————- | | certificate_associated | #get_certificate_association | 15 | 8 | | certificate_disassociated | #get_certificate_association | 15 | 8 | | inbound_external_link_active | #get_inbound_external_link | 30 | 5 | | inbound_external_link_deleted | #get_inbound_external_link | 30 | 5 | | link_accepted | #get_link | 30 | 5 | | link_active | #get_link | 30 | 5 | | link_deleted | #get_link | 30 | 5 | | link_routing_rule_active | #get_link_routing_rule | 5 | 24 | | link_routing_rule_deleted | #get_link_routing_rule | 5 | 24 | | outbound_external_link_active | #get_outbound_external_link | 30 | 5 | | outbound_external_link_deleted | #get_outbound_external_link | 30 | 5 | | requester_gateway_active | #get_requester_gateway | 30 | 5 | | requester_gateway_deleted | #get_requester_gateway | 30 | 5 | | responder_gateway_active | #get_responder_gateway | 30 | 5 | | responder_gateway_deleted | #get_responder_gateway | 30 | 5 |
3822 3823 3824 3825 3826 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3822 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3830 3831 3832 |
# File 'lib/aws-sdk-rtbfabric/client.rb', line 3830 def waiter_names waiters.keys end |