Class: Aws::RTBFabric::Types::CreateResponderGatewayRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::CreateResponderGatewayRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The unique client token.
-
#description ⇒ String
An optional description for the responder gateway.
-
#domain_name ⇒ String
The domain name for the responder gateway.
-
#gateway_type ⇒ String
The type of gateway.
-
#listener_config ⇒ Types::ListenerConfig
Listener configuration for the protocols (HTTP, HTTPS, or both) accepted by the gateway.
-
#managed_endpoint_configuration ⇒ Types::ManagedEndpointConfiguration
The configuration for the managed endpoint.
-
#port ⇒ Integer
The networking port to use.
-
#protocol ⇒ String
The networking protocol to use.
-
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups.
-
#subnet_ids ⇒ Array<String>
The unique identifiers of the subnets.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
-
#trust_store_configuration ⇒ Types::TrustStoreConfiguration
The configuration of the trust store.
-
#vpc_id ⇒ String
The unique identifier of the Virtual Private Cloud (VPC).
Instance Attribute Details
#client_token ⇒ String
The unique client token.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description for the responder gateway.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name for the responder gateway.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#gateway_type ⇒ String
The type of gateway. Valid values are ‘EXTERNAL` or `INTERNAL`.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#listener_config ⇒ Types::ListenerConfig
Listener configuration for the protocols (HTTP, HTTPS, or both) accepted by the gateway.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#managed_endpoint_configuration ⇒ Types::ManagedEndpointConfiguration
The configuration for the managed endpoint.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The networking port to use.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The networking protocol to use.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The unique identifiers of the subnets.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs of the tag or tags to assign to the resource.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#trust_store_configuration ⇒ Types::TrustStoreConfiguration
The configuration of the trust store.
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The unique identifier of the Virtual Private Cloud (VPC).
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 731 class CreateResponderGatewayRequest < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :client_token, :description, :tags, :gateway_type) SENSITIVE = [] include Aws::Structure end |