Class: Aws::RTBFabric::Types::GetInboundExternalLinkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::GetInboundExternalLinkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Types::LinkAttributes
Attributes of the link.
-
#connectivity_type ⇒ String
The connectivity type of the link.
-
#created_at ⇒ Time
The timestamp of when the inbound external link was created.
-
#domain_name ⇒ String
The domain name.
-
#flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of flow modules.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#link_id ⇒ String
The unique identifier of the link.
-
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
-
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of pending flow modules.
-
#status ⇒ String
The status of the request.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
-
#updated_at ⇒ Time
The timestamp of when the inbound external link was updated.
Instance Attribute Details
#attributes ⇒ Types::LinkAttributes
Attributes of the link.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#connectivity_type ⇒ String
The connectivity type of the link.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the inbound external link was created.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of flow modules.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#link_id ⇒ String
The unique identifier of the link.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of pending flow modules.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the request.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the inbound external link was updated.
1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1205 class GetInboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :domain_name, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |