Class: Aws::RTBFabric::Types::GetOutboundExternalLinkResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesTypes::LinkAttributes

Describes the attributes of a link.



1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#connectivity_typeString

The connectivity type of the link.

Returns:

  • (String)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp of when the outbound external link was created.

Returns:

  • (Time)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#flow_modulesArray<Types::ModuleConfiguration>

The configuration of flow modules.

Returns:



1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The unique identifier of the gateway.

Returns:

  • (String)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

The unique identifier of the link.

Returns:

  • (String)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_settingsTypes::LinkLogSettings

Settings for the application logs.



1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#pending_flow_modulesArray<Types::ModuleConfiguration>

The configuration of pending flow modules.

Returns:



1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#public_endpointString

The public endpoint for the link.

Returns:

  • (String)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the request.

Returns:

  • (String)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of the key-value pairs for the tag or tags assigned to the specified resource.

Returns:

  • (Hash<String,String>)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when the outbound external link was updated.

Returns:

  • (Time)


1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465

class GetOutboundExternalLinkResponse < Struct.new(
  :gateway_id,
  :link_id,
  :status,
  :public_endpoint,
  :flow_modules,
  :pending_flow_modules,
  :attributes,
  :created_at,
  :updated_at,
  :tags,
  :log_settings,
  :connectivity_type)
  SENSITIVE = []
  include Aws::Structure
end