Class: Aws::RTBFabric::Types::GetOutboundExternalLinkResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::GetOutboundExternalLinkResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Types::LinkAttributes
Describes the attributes of a link.
-
#connectivity_type ⇒ String
The connectivity type of the link.
-
#created_at ⇒ Time
The timestamp of when the outbound external link was created.
-
#flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of flow modules.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#link_id ⇒ String
The unique identifier of the link.
-
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
-
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of pending flow modules.
-
#public_endpoint ⇒ String
The public endpoint for the link.
-
#status ⇒ String
The status of the request.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
-
#updated_at ⇒ Time
The timestamp of when the outbound external link was updated.
Instance Attribute Details
#attributes ⇒ Types::LinkAttributes
Describes the attributes of a link.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#connectivity_type ⇒ String
The connectivity type of the link.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the outbound external link was created.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of flow modules.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#link_id ⇒ String
The unique identifier of the link.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#log_settings ⇒ Types::LinkLogSettings
Settings for the application logs.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#pending_flow_modules ⇒ Array<Types::ModuleConfiguration>
The configuration of pending flow modules.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#public_endpoint ⇒ String
The public endpoint for the link.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the request.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the outbound external link was updated.
1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1465 class GetOutboundExternalLinkResponse < Struct.new( :gateway_id, :link_id, :status, :public_endpoint, :flow_modules, :pending_flow_modules, :attributes, :created_at, :updated_at, :tags, :log_settings, :connectivity_type) SENSITIVE = [] include Aws::Structure end |