Class: Aws::RTBFabric::Types::GetResponderGatewayResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::GetResponderGatewayResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#active_links_count ⇒ Integer
The count of active links for the responder gateway.
-
#created_at ⇒ Time
The timestamp of when the responder gateway was created.
-
#description ⇒ String
The description of the responder gateway.
-
#domain_name ⇒ String
The domain name of the responder gateway.
-
#external_inbound_endpoint ⇒ String
The external inbound endpoint for the responder gateway.
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#gateway_type ⇒ String
The type of gateway.
-
#inbound_links_count ⇒ Integer
Deprecated.
-
#links_requested_count ⇒ Integer
The count of requested links waiting for the responder gateway to accept or reject.
-
#listener_config ⇒ Types::ListenerConfig
The listener configuration for the responder gateway.
-
#managed_endpoint_configuration ⇒ Types::ManagedEndpointConfiguration
The configuration of the managed endpoint.
-
#port ⇒ Integer
The networking port.
-
#protocol ⇒ String
The networking protocol.
-
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups.
-
#status ⇒ String
The status of the request.
-
#subnet_ids ⇒ Array<String>
The unique identifiers of the subnets.
-
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
-
#total_links_count ⇒ Integer
The total count of links for the responder gateway.
-
#trust_store_configuration ⇒ Types::TrustStoreConfiguration
The configuration of the trust store.
-
#updated_at ⇒ Time
The timestamp of when the responder gateway was updated.
-
#vpc_id ⇒ String
The unique identifier of the Virtual Private Cloud (VPC).
Instance Attribute Details
#active_links_count ⇒ Integer
The count of active links for the responder gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the responder gateway was created.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the responder gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain name of the responder gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#external_inbound_endpoint ⇒ String
The external inbound endpoint for the responder gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#gateway_id ⇒ String
The unique identifier of the gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#gateway_type ⇒ String
The type of gateway. Valid values are ‘EXTERNAL` or `INTERNAL`.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#inbound_links_count ⇒ Integer
Deprecated. Use ‘linksRequestedCount’ instead.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#links_requested_count ⇒ Integer
The count of requested links waiting for the responder gateway to accept or reject.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#listener_config ⇒ Types::ListenerConfig
The listener configuration for the responder gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#managed_endpoint_configuration ⇒ Types::ManagedEndpointConfiguration
The configuration of the managed endpoint.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The networking port.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The networking protocol.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the request.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The unique identifiers of the subnets.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of the key-value pairs for the tag or tags assigned to the specified resource.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#total_links_count ⇒ Integer
The total count of links for the responder gateway.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#trust_store_configuration ⇒ Types::TrustStoreConfiguration
The configuration of the trust store.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the responder gateway was updated.
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The unique identifier of the Virtual Private Cloud (VPC).
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1662 class GetResponderGatewayResponse < Struct.new( :vpc_id, :subnet_ids, :security_group_ids, :status, :description, :created_at, :updated_at, :domain_name, :port, :protocol, :listener_config, :trust_store_configuration, :managed_endpoint_configuration, :gateway_id, :tags, :active_links_count, :total_links_count, :inbound_links_count, :links_requested_count, :gateway_type, :external_inbound_endpoint) SENSITIVE = [] include Aws::Structure end |