Class: Aws::RTBFabric::Types::GetResponderGatewayResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rtbfabric/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The count of active links for the responder gateway.

Returns:

  • (Integer)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp of when the responder gateway was created.

Returns:

  • (Time)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the responder gateway.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The domain name of the responder gateway.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#external_inbound_endpointString

The external inbound endpoint for the responder gateway.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_idString

The unique identifier of the gateway.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#gateway_typeString

The type of gateway. Valid values are ‘EXTERNAL` or `INTERNAL`.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

The count of inbound links for the responder gateway.

Returns:

  • (Integer)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#listener_configTypes::ListenerConfig

The listener configuration for the responder gateway.



1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#managed_endpoint_configurationTypes::ManagedEndpointConfiguration

The configuration of the managed endpoint.



1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The networking port.

Returns:

  • (Integer)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The networking protocol.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The unique identifiers of the security groups.

Returns:

  • (Array<String>)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the request.

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The unique identifiers of the subnets.

Returns:

  • (Array<String>)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of the key-value pairs for the tag or tags assigned to the specified resource.

Returns:

  • (Hash<String,String>)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

The total count of links for the responder gateway.

Returns:

  • (Integer)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#trust_store_configurationTypes::TrustStoreConfiguration

The configuration of the trust store.



1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when the responder gateway was updated.

Returns:

  • (Time)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The unique identifier of the Virtual Private Cloud (VPC).

Returns:

  • (String)


1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
# File 'lib/aws-sdk-rtbfabric/types.rb', line 1657

class GetResponderGatewayResponse < Struct.new(
  :vpc_id,
  :subnet_ids,
  :security_group_ids,
  :status,
  :description,
  :created_at,
  :updated_at,
  :domain_name,
  :port,
  :protocol,
  :listener_config,
  :trust_store_configuration,
  :managed_endpoint_configuration,
  :gateway_id,
  :tags,
  :active_links_count,
  :total_links_count,
  :inbound_links_count,
  :gateway_type,
  :external_inbound_endpoint)
  SENSITIVE = []
  include Aws::Structure
end