Class: Aws::RTBFabric::Types::ListCertificateAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ListCertificateAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateway_id ⇒ String
The unique identifier of the gateway.
-
#max_results ⇒ Integer
The maximum number of results that are returned per call.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#gateway_id ⇒ String
The unique identifier of the gateway.
2036 2037 2038 2039 2040 2041 2042 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2036 class ListCertificateAssociationsRequest < Struct.new( :gateway_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results that are returned per call. You can
use nextToken to obtain further pages of results.
This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.
2036 2037 2038 2039 2040 2041 2042 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2036 class ListCertificateAssociationsRequest < Struct.new( :gateway_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2036 2037 2038 2039 2040 2041 2042 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2036 class ListCertificateAssociationsRequest < Struct.new( :gateway_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |