Class: Aws::RTBFabric::Types::ListCertificateAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ListCertificateAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_associations ⇒ Array<Types::CertificateAssociationSummary>
The list of certificate associations for the gateway.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#certificate_associations ⇒ Array<Types::CertificateAssociationSummary>
The list of certificate associations for the gateway.
2059 2060 2061 2062 2063 2064 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2059 class ListCertificateAssociationsResponse < Struct.new( :certificate_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2059 2060 2061 2062 2063 2064 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2059 class ListCertificateAssociationsResponse < Struct.new( :certificate_associations, :next_token) SENSITIVE = [] include Aws::Structure end |