Class: Aws::RTBFabric::Types::ListLinkRoutingRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ListLinkRoutingRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#rules ⇒ Array<Types::LinkRoutingRuleSummary>
The list of routing rules for the link.
Instance Attribute Details
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2117 2118 2119 2120 2121 2122 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2117 class ListLinkRoutingRulesResponse < Struct.new( :rules, :next_token) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::LinkRoutingRuleSummary>
The list of routing rules for the link.
2117 2118 2119 2120 2121 2122 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2117 class ListLinkRoutingRulesResponse < Struct.new( :rules, :next_token) SENSITIVE = [] include Aws::Structure end |