Class: Aws::RTBFabric::Types::ListRequesterGatewaysResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ListRequesterGatewaysResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateway_ids ⇒ Array<String>
The unique identifier of the gateways.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#gateway_ids ⇒ Array<String>
The unique identifier of the gateways.
2298 2299 2300 2301 2302 2303 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2298 class ListRequesterGatewaysResponse < Struct.new( :gateway_ids, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2298 2299 2300 2301 2302 2303 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2298 class ListRequesterGatewaysResponse < Struct.new( :gateway_ids, :next_token) SENSITIVE = [] include Aws::Structure end |