Class: Aws::RTBFabric::Types::ListResponderGatewaysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ListResponderGatewaysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned per call.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned per call. You can
use nextToken to obtain further pages of results.
This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.
2324 2325 2326 2327 2328 2329 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2324 class ListResponderGatewaysRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2324 2325 2326 2327 2328 2329 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2324 class ListResponderGatewaysRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |