Class: Aws::RTBFabric::Types::ManagedEndpointConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::ManagedEndpointConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
ManagedEndpointConfiguration is a union - when making an API calls you must set exactly one of the members.
ManagedEndpointConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ManagedEndpointConfiguration corresponding to the set member.
Describes the configuration of a managed endpoint.
Direct Known Subclasses
Defined Under Namespace
Classes: AutoScalingGroups, EksEndpoints, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_groups ⇒ Types::AutoScalingGroupsConfiguration
Describes the configuration of an auto scaling group.
-
#eks_endpoints ⇒ Types::EksEndpointsConfiguration
Describes the configuration of an Amazon Elastic Kubernetes Service endpoint.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#auto_scaling_groups ⇒ Types::AutoScalingGroupsConfiguration
Describes the configuration of an auto scaling group.
2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2283 class ManagedEndpointConfiguration < Struct.new( :auto_scaling_groups, :eks_endpoints, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AutoScalingGroups < ManagedEndpointConfiguration; end class EksEndpoints < ManagedEndpointConfiguration; end class Unknown < ManagedEndpointConfiguration; end end |
#eks_endpoints ⇒ Types::EksEndpointsConfiguration
Describes the configuration of an Amazon Elastic Kubernetes Service endpoint.
2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2283 class ManagedEndpointConfiguration < Struct.new( :auto_scaling_groups, :eks_endpoints, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AutoScalingGroups < ManagedEndpointConfiguration; end class EksEndpoints < ManagedEndpointConfiguration; end class Unknown < ManagedEndpointConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2283 2284 2285 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2283 def unknown @unknown end |