Class: Aws::RTBFabric::Types::QueryStringKeyValuePair
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::QueryStringKeyValuePair
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
A key-value pair for query string matching in a routing rule condition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The key of the query string parameter to match.
-
#value ⇒ String
The value of the query string parameter to match.
Instance Attribute Details
#key ⇒ String
The key of the query string parameter to match. Must contain only RFC 3986 unreserved characters.
2442 2443 2444 2445 2446 2447 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2442 class QueryStringKeyValuePair < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the query string parameter to match. Must contain only RFC 3986 unreserved characters.
2442 2443 2444 2445 2446 2447 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2442 class QueryStringKeyValuePair < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |