Class: Aws::RTBFabric::Types::RuleCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::RTBFabric::Types::RuleCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rtbfabric/types.rb
Overview
The conditions for a routing rule. All specified fields must match for the rule to apply (AND logic). At least one condition field must be set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#host_header ⇒ String
The exact host header value to match.
-
#host_header_wildcard ⇒ String
A wildcard pattern for host header matching (for example, ‘*.example.com`).
-
#path_exact ⇒ String
The exact path to match.
-
#path_prefix ⇒ String
The path prefix to match.
-
#query_string_equals ⇒ Types::QueryStringKeyValuePair
A query string key-value pair that must be present and match exactly.
-
#query_string_exists ⇒ String
A query string key that must be present in the request (any value is accepted).
Instance Attribute Details
#host_header ⇒ String
The exact host header value to match.
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2624 class RuleCondition < Struct.new( :host_header, :host_header_wildcard, :path_prefix, :path_exact, :query_string_equals, :query_string_exists) SENSITIVE = [] include Aws::Structure end |
#host_header_wildcard ⇒ String
A wildcard pattern for host header matching (for example, ‘*.example.com`).
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2624 class RuleCondition < Struct.new( :host_header, :host_header_wildcard, :path_prefix, :path_exact, :query_string_equals, :query_string_exists) SENSITIVE = [] include Aws::Structure end |
#path_exact ⇒ String
The exact path to match. Must start with ‘/`.
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2624 class RuleCondition < Struct.new( :host_header, :host_header_wildcard, :path_prefix, :path_exact, :query_string_equals, :query_string_exists) SENSITIVE = [] include Aws::Structure end |
#path_prefix ⇒ String
The path prefix to match. The request path must start with this value. Must start with ‘/`.
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2624 class RuleCondition < Struct.new( :host_header, :host_header_wildcard, :path_prefix, :path_exact, :query_string_equals, :query_string_exists) SENSITIVE = [] include Aws::Structure end |
#query_string_equals ⇒ Types::QueryStringKeyValuePair
A query string key-value pair that must be present and match exactly.
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2624 class RuleCondition < Struct.new( :host_header, :host_header_wildcard, :path_prefix, :path_exact, :query_string_equals, :query_string_exists) SENSITIVE = [] include Aws::Structure end |
#query_string_exists ⇒ String
A query string key that must be present in the request (any value is accepted).
2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/aws-sdk-rtbfabric/types.rb', line 2624 class RuleCondition < Struct.new( :host_header, :host_header_wildcard, :path_prefix, :path_exact, :query_string_equals, :query_string_exists) SENSITIVE = [] include Aws::Structure end |