Class: Aws::RTBFabric::Waiters::CertificateAssociated
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::CertificateAssociated
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CertificateAssociated
constructor
A new instance of CertificateAssociated.
-
#wait(params = {}) ⇒ Types::GetCertificateAssociationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CertificateAssociated
Returns a new instance of CertificateAssociated.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 98 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 8, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :get_certificate_association, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ASSOCIATED" }, { "matcher" => "error", "state" => "failure", "expected" => "ResourceNotFoundException" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DISASSOCIATED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "PENDING_DISASSOCIATION" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
147 148 149 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 147 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetCertificateAssociationResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#acm_certificate_arn => String
-
#status => String
-
#associated_at => Time
-
#updated_at => Time
142 143 144 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 142 def wait(params = {}) @waiter.wait(client: @client, params: params) end |