Class: Aws::RTBFabric::Waiters::LinkDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::LinkDeleted
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LinkDeleted
constructor
A new instance of LinkDeleted.
-
#wait(params = {}) ⇒ Types::GetLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LinkDeleted
Returns a new instance of LinkDeleted.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 438 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_link, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "REJECTED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
476 477 478 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 476 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLinkResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#peer_gateway_id => String
-
#status => String
-
#created_at => Time
-
#updated_at => Time
-
#direction => String
-
#flow_modules => Array<Types::ModuleConfiguration>
-
#pending_flow_modules => Array<Types::ModuleConfiguration>
-
#attributes => Types::LinkAttributes
-
#log_settings => Types::LinkLogSettings
-
#connectivity_type => String
-
#link_id => String
-
#tags => Hash<String,String>
-
#http_responder_allowed => Boolean
-
#timeout_in_millis => Integer
471 472 473 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 471 def wait(params = {}) @waiter.wait(client: @client, params: params) end |