Class: Aws::RTBFabric::Waiters::OutboundExternalLinkDeleted
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::OutboundExternalLinkDeleted
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ OutboundExternalLinkDeleted
constructor
A new instance of OutboundExternalLinkDeleted.
-
#wait(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ OutboundExternalLinkDeleted
Returns a new instance of OutboundExternalLinkDeleted.
649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 649 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_outbound_external_link, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "REJECTED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
687 688 689 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 687 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetOutboundExternalLinkResponse
Returns a response object which responds to the following methods:
-
#gateway_id => String
-
#link_id => String
-
#status => String
-
#public_endpoint => String
-
#flow_modules => Array<Types::ModuleConfiguration>
-
#pending_flow_modules => Array<Types::ModuleConfiguration>
-
#attributes => Types::LinkAttributes
-
#created_at => Time
-
#updated_at => Time
-
#tags => Hash<String,String>
-
#log_settings => Types::LinkLogSettings
-
#connectivity_type => String
682 683 684 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 682 def wait(params = {}) @waiter.wait(client: @client, params: params) end |