Class: Aws::RTBFabric::Waiters::RequesterGatewayActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::RequesterGatewayActive
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RequesterGatewayActive
constructor
A new instance of RequesterGatewayActive.
-
#wait(params = {}) ⇒ Types::GetRequesterGatewayResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RequesterGatewayActive
Returns a new instance of RequesterGatewayActive.
699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 699 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_requester_gateway, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ERROR" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
737 738 739 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 737 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRequesterGatewayResponse
Returns a response object which responds to the following methods:
-
#status => String
-
#domain_name => String
-
#description => String
-
#created_at => Time
-
#updated_at => Time
-
#vpc_id => String
-
#subnet_ids => Array<String>
-
#security_group_ids => Array<String>
-
#gateway_id => String
-
#tags => Hash<String,String>
-
#active_links_count => Integer
-
#total_links_count => Integer
732 733 734 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 732 def wait(params = {}) @waiter.wait(client: @client, params: params) end |