Class: Aws::RTBFabric::Waiters::ResponderGatewayActive
- Inherits:
-
Object
- Object
- Aws::RTBFabric::Waiters::ResponderGatewayActive
- Defined in:
- lib/aws-sdk-rtbfabric/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ResponderGatewayActive
constructor
A new instance of ResponderGatewayActive.
-
#wait(params = {}) ⇒ Types::GetResponderGatewayResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ResponderGatewayActive
Returns a new instance of ResponderGatewayActive.
798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 798 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_responder_gateway, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "ACTIVE" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ERROR" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
836 837 838 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 836 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetResponderGatewayResponse
Returns a response object which responds to the following methods:
-
#vpc_id => String
-
#subnet_ids => Array<String>
-
#security_group_ids => Array<String>
-
#status => String
-
#description => String
-
#created_at => Time
-
#updated_at => Time
-
#domain_name => String
-
#port => Integer
-
#protocol => String
-
#listener_config => Types::ListenerConfig
-
#trust_store_configuration => Types::TrustStoreConfiguration
-
#managed_endpoint_configuration => Types::ManagedEndpointConfiguration
-
#gateway_id => String
-
#tags => Hash<String,String>
-
#active_links_count => Integer
-
#total_links_count => Integer
-
#inbound_links_count => Integer
-
#links_requested_count => Integer
-
#gateway_type => String
-
#external_inbound_endpoint => String
831 832 833 |
# File 'lib/aws-sdk-rtbfabric/waiters.rb', line 831 def wait(params = {}) @waiter.wait(client: @client, params: params) end |